@@ -291,13 +291,19 @@ class RestChannelAsyncClient:
         self._lock = threading.Lock()
 
     def __enter__(self):
-        self._thread.start()
-        _logger.info('RestChannelAsyncClient started.')
+        self.start()
         return self
 
     def __exit__(self, exc_type, exc_value, traceback):
         self.close()
 
+    def start(self) -> None:
+        """
+        Starts the asynchronous client and the heartbeat thread.
+        """
+        self._thread.start()
+        _logger.info('RestChannelAsyncClient started.')
+
     def close(self) -> None:
         """
         Stops the asynchronous client and terminates the heartbeat thread.
@@ -356,9 +362,9 @@ class RestChannelAsyncClient:
 
             if err:
                 if self._on_hb_error:
-                    self._on_hb_error(e)
+                    self._on_hb_error(err)
                 else:
-                    _logger.error(f'Error during sending heartbeat [error={e}]', exc_info=True)
+                    _logger.error(f'Error during sending heartbeat [error={err}]', exc_info=True)
 
             self._on_srv_messages(resp)
 
