@@ -215,7 +215,7 @@ class ChannelType(StrEnum):
     SMS = 'SMS'
     '''SMS channel type.'''
 
-    REST = 'rest'
+    REST = 'REST'
     '''Rest channel type.'''
 
     WHATSUP = 'whatsup'
